@@ -28,11 +28,11 @@
 #include "konqsettingsxt.h"
 #include "konqsettings.h"
 
-#include <QDebug>
+#include "konqdebug.h"
 #include <kwindowsystem.h>
 #include <KStartupInfo>
 
-#include <QtCore/QFile>
+#include <QFile>
 #if KONQ_HAVE_X11
 #include <QX11Info>
 #endif
